doapfiend.model.SVNRepository

Package doapfiend :: Module model :: Class SVNRepository |
[hide private]
[frames] | no frames]

# Class SVNRepository

source code

          object --+
                   |
    utils.rdfSubject --+
                       |
                      SVNRepository

Subversion repository classs

Instance Methods | [hide private]
Inherited from `utils.rdfSubject`: `__delitem__`, `__getitem__`, `__init__`, `__repr__`, `md5_term_hash`, `n3` Inherited from `utils.rdfSubject` (private): `_ppo`, `_remove`, `_rename`, `_set_with_dict` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `utils.rdfSubject`: `ClassInstances`, `GetRandom`, `filter_by`, `get_by`, `query` Inherited from `utils.rdfSubject` (private): `_getdescriptor`

Class Variables | [hide private]
| rdf_type = `rdflib.URIRef('http://usefulinc.com/ns/doap#SVNRepo`...``
| location = `rdfSingle(DOAP.location)`
| svn_browse = `rdfSingle(DOAP.browse)`
Inherited from `utils.rdfSubject`: `db`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### rdf_type Value:
      rdflib.URIRef('http://usefulinc.com/ns/doap#SVNRepository')